#!/bin/bash
##################
#                #
#    PAS v0.5    #
#                #
##################
#
# This is a quick and dirty but still quite awesome script to switch ALSA
# output on the fly. It copies valid config files to enable output
# devices on demand.
# As of version 0.5 two templates are provided:
#
# 1. BT output -> .asoundrc_bt
# 2. HW output -> .asoundrc_hw
#
# You only need to add a valid device MAC address to .asoundrc_bt
# and save it as .asoundrc_outputname
# Make then use of it with: pas.sh -o outputname
# For every outputname you need a .asoundrc_outputname file!
# 
# Please save your own customized .asoundrc files in PAS_PATH.
# Because of libpnd it is best to avoid ~ and use absolute paths here:

PAS_PATH=/home/${USER}/pas/

# Before any sound is being played ALSA parses the config files, so
# there's NO need to restart your system after you used this script.
#
# Please set PAS_PATH correctly!

if [[ $# = 0 ]]; then
        echo "No options parsed. Try "$0" --help"
fi

while [[ $# > 0 ]]
do
key="$1"

case $key in
	-o|--output)
	OUTPUT="$2"
	shift
	if [ -f ${PAS_PATH}.asoundrc_${OUTPUT} ];then
		echo "Switching audio output to: "${OUTPUT}
		echo "using config files from: "${PAS_PATH}
		rm -v /home/${USER}/.asoundrc
                cp -v ${PAS_PATH}.asoundrc_${OUTPUT} /home/${USER}/.asoundrc
	else
		echo "Unsupported output mode parsed. Exiting."
		echo "For every -o outputname you need a .asoundrc_outputname file!"
	fi
	;;
	-h|--help)
	echo "##################"
	echo "#                #"
	echo "#    PAS v0.5    #"
	echo "#                #"
	echo "##################"
	echo
	echo "Pandora Audio Switch v0.5"
	echo "-------------------------"
	echo "Usage:"
	echo "-h|--help 	Display this message."
	echo "-o|--output	Set audio output device."
	echo
	echo "Example: ./pas.sh -o bt_headset"
	echo "         ./pas.sh -o boombox"
	echo
	;;
	*)
	echo "Unknown option parsed. Exiting."
	;;
esac
shift
done
